==> ucscsdk-0.9.0.2.tar.gz: ucscsdk-0.9.0.2/ucscsdk/mometa/compute/ComputeFabricFcMonSrcEpCont.py <==
"""This module contains the general information for ComputeFabricFcMonSrcEpCont ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputeFabricFcMonSrcEpContConsts():
    pass


class ComputeFabricFcMonSrcEpCont(ManagedObject):
    """This is ComputeFabricFcMonSrcEpCont class."""

    consts = ComputeFabricFcMonSrcEpContConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputeFabricFcMonSrcEpCont", "computeFabricFcMonSrcEpCont", "fc-mon", VersionMeta.Version201b, "InputOutput", 0xf, [], ["admin", "operations"], [u'computeSystem'], [u'computeFabricFcMonSrcEp'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.id = None
        self.status = None

        ManagedObject.__init__(self, "ComputeFabricFcMonSrcEpCont", parent_mo_or_dn, **kwargs)

==> ucscsdk-0.9.0.10.tar.gz: ucscsdk-0.9.0.10/ucscsdk/mometa/compute/ComputeFabricFcMonSrcEpCont.py <==
"""This module contains the general information for ComputeFabricFcMonSrcEpCont ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputeFabricFcMonSrcEpContConsts():
    pass


class ComputeFabricFcMonSrcEpCont(ManagedObject):
    """This is ComputeFabricFcMonSrcEpCont class."""

    consts = ComputeFabricFcMonSrcEpContConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputeFabricFcMonSrcEpCont", "computeFabricFcMonSrcEpCont", "fc-mon", VersionMeta.Version201b, "InputOutput", 0xf, [], ["admin", "operations"], ['computeSystem'], ['computeFabricFcMonSrcEp'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.id = None
        self.status = None

        ManagedObject.__init__(self, "ComputeFabricFcMonSrcEpCont", parent_mo_or_dn, **kwargs)
